"""Top-level package for Coding Dojo Data Science."""

__author__ = """James Irving"""
__email__ = 'james.irving.phd@gmail.com'
__version__ = '0.2.1'

from cdds import datasets
from cdds.inspect import check_package_versions
from cdds import inspect
from cdds import filetools
from cdds import utils

from cdds.inspect import ihelp 